.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

Arrays
::::::::::::::::::::

Class Periods: 6-8

AP CSA Exam Weighting: 10-15%

.. toctree::
   :maxdepth: 3

   topic-6-1-array-basics.rst
   topic-6-2-traversing-arrays.rst
   topic-6-3-arrays-with-foreach.rst
   topic-6-4-array-algorithms.rst
   topic-6-5-summary.rst
   ArrayParsonsPractice.rst
   Arrays-mixed-code-toggle.rst
   ArrayPractice.rst
   Exercises.rst
   arrayExam.rst
